@@ -1,6 +1,9 @@
 from django import template
+from django.conf import settings
 from django.db import models
 
+from django_markdown.utils import markdown
+
 register = template.Library()
 
 from ..models import Blurb
@@ -17,7 +20,7 @@ def get_blurb (bkey):
     
   else:
     if b.content:
-      ret = b.content
+      ret = markdown(b.content, extensions=settings.MARKDOWN_EXTENSIONS)
       
   if ret is None:
     ret = 'No content found for {}'.format(bkey)
